/*
 * DC Receiver controller board definitions
 * 
 * OH2NLT / Juha Niinikoski 25.13.2003
 *
 * Tone I/O added 03.02.2005
 * TX signal added 20.06.2005
 * 16F88 alternative added 28.08.2005
 */

#define XTAL 	20000000 // CPU clock, Hz

/* PIC16F88 additional registers */



/*	Port A used for A/D inputs & control signals	*/

#ifdef F88
#define ANSEL_INIT	0x00	/* all pins for digital I/O */
#define	ANSEL_MEAS	0x03	/* AN0 and AN1 in use */
#define	ADCON1_INIT 0x80	/* default state, internal Vref */
#else
#define	ADCON1_INIT 0x87	/* default state, PORTA = digital I/O */
#define ADCON1_MEAS	0x84	/* Right justified, 3/1 mode */
#endif

#define ADCON0_CH0	0xC1	/* Setup for CH0 */
#define ADCON0_CH1	0xC9	/* Setup for CC1 */
#define ADCON0_OFF	0x00	/* A/D system off */

#define	TRISA_INIT	0b11100011
#define	PORTA_INIT	0x00

#define TONE_DIR	TRISA0	/* tone I/O direction bit */
#define TONE_OUT	RA0		/* send beep tone to battery voltage measurement circuit */

#define	LCD_E		RA4		/* LCD control signals */
#define	LCD_RS		RA3

#define AD_FSYNC	RA2		/* DDS Chip signals */
#define AD_SCLK		RB1
#define AD_SDATA	RB0


/*	Port B used for LCD Data & Switch inputs & DDS control	*/

#define PORTB_INIT	0b00000000	/* PORTB init data */
#define TRISB_INIT	0x00			// default state, all outputs
#define TRISB_READ	0b11110000		// switch read state, do not change DDS control bits !

#define	LCD_DATA	PORTB

/* PORTB read bit masks */

#define BUTTON_1	(1<<5)			// encoder push button
#define TX			(1<<4)			// TX signal, 0=TX
#define ENCODER_A	(1<<7)			// encoder I/Q bits
#define ENCODER_B	(1<<6)

#define SW1			RB5				// encoder push button at I/O
#define TEST_OUT	RB5
#define TEST_OUT_TS	TRISB4			// test signal output

/*   Define unsigned data types   */

#ifndef _BYTE_DEFINED_
#define _BYTE_DEFINED_

typedef unsigned char BYTE;
typedef unsigned int WORD;
typedef unsigned long LWORD;

#endif


/*   Define Boolean data type   */

#ifndef _BOOL_DEFINED_
#define _BOOL_DEFINED_

typedef BYTE BOOL;

#define FALSE 0
#define TRUE 1

#endif

/*   Define null pointer   */

#ifndef NULL
#define NULL (void *)0
#endif


